fn match_trigger_bv(
trigger: &Trigger,
name: &Token,
cmp: Comparator,
bv: &BV,
data: &Everything,
sc: &mut ScopeContext,
tooltipped: Tooltipped,
negated: bool,
max_sev: Severity,
) -> boolExpand description
Takes a Trigger and a trigger field, and validates that the constraints
specified by the Trigger hold.
Returns true iff the trigger had side effects (such as saving scopes).