pub fn partition(token: &Token) -> Vec<Part>Expand description
This function partitions the input token into parts separated by .. Each part may contain either a token
or a token-argument pair when using the ()-syntax, e.g. "prowess_diff(liege)". It does not validate the tokens
or arguments, but simply parses and detects any syntactical errors.