pub fn scope_trigger(
name: &Token,
data: &Everything,
) -> Option<(Scopes, Trigger)>Expand description
Look up a trigger token that evaluates to a trigger value.
name is the token. data is used in special cases to verify the name dynamically,
for example, <lifestyle>_xp is only a valid trigger if <lifestyle> is present in
the database.
Returns the inscopes valid for the trigger and the output trigger value type.