pub fn validate_argument(
part_flags: PartFlags,
part: &Token,
func: &Token,
arg: &Token,
data: &Everything,
sc: &mut ScopeContext,
)Expand description
Validate that the argument passed through is valid, either being of a complex trigger compare value, or a scope prefix.