pub fn validate_trigger(
block: &Block,
data: &Everything,
sc: &mut ScopeContext,
tooltipped: Tooltipped,
) -> boolExpand description
The standard interface to trigger validation. Validates a trigger in the given ScopeContext.
tooltipped determines what warnings are emitted related to tooltippability of the triggers
inside the block.
Returns true iff the trigger had side effects (such as saving scopes).