pub fn validate_trigger_internal(
caller: &Lowercase<'_>,
ltype: ListType,
block: &Block,
data: &Everything,
sc: &mut ScopeContext,
vd: Validator<'_>,
tooltipped: Tooltipped,
negated: bool,
) -> boolExpand description
The interface to trigger validation when validate_trigger is too limited.
caller is the key that opened this trigger. It is used to determine which special cases apply.
For example, if caller is trigger_if then a limit block is expected.
in_list specifies whether this trigger is directly in an any_ iterator. It is also used to
determine which special cases apply.
negated is true iff this trigger is tested in a negative sense, for example if it is
somewhere inside a NOT = { ... } block. negated is propagated to all sub-blocks and is
flipped when another NOT or similar is encountered inside this one.
Returns true iff the trigger had side effects (such as saving scopes).