pub fn validate_trigger_key_bv(
key: &Token,
cmp: Comparator,
bv: &BV,
data: &Everything,
sc: &mut ScopeContext,
tooltipped: Tooltipped,
negated: bool,
max_sev: Severity,
) -> boolExpand description
Validate a trigger given its key and argument. It is like validate_trigger_internal except
that all special cases are assumed to have been handled. This is the interface used for the
switch effect, where the key and argument are not together in the script.
Returns true iff the trigger had side effects (such as saving scopes).